==> pymks-0.3.3.tar.gz: pymks-0.3.3/setup.py <==
#!/usr/bin/env python

import subprocess
from setuptools import setup, find_packages
import os



def make_version():
    """Generates a version number using `git describe`.

    Returns:
      version number of the form "3.1.1.dev127+g413ed61".
    """
    def _minimal_ext_cmd(cmd):
        """Run a command in a subprocess.

        Args:
          cmd: list of the command

        Returns:
          output from the command
        """
        # construct minimal environment
        env = {}
        for k in ['SYSTEMROOT', 'PATH']:
            value = os.environ.get(k)
            if value is not None:
                env[k] = value
        # LANGUAGE is used on win32
        env['LANGUAGE'] = 'C'
        env['LANG'] = 'C'
        env['LC_ALL'] = 'C'
        out = subprocess.Popen(cmd,
                               stdout=subprocess.PIPE,
                               env=env).communicate()[0]
        return out

    version = 'unknown'

    if os.path.exists('.git'):
        try:
            out = _minimal_ext_cmd(['git',
                                    'describe',
                                    '--tags',
                                    '--match',
                                    'v*'])
            # ticket:475 - fix for bytecode received in Py3k
            # http://jeetworks.org/node/67
            outdecode = out.decode("utf-8")
            # convert git long-form version string, e.g.,
            # "version-3_1_1-127-g413ed61", into PEP 440 version,
            # e.g., "3.1.1.dev127+g413ed61"
            version = outdecode.strip().split("-")
            if len(version) > 1:
                version, dev, sha = version
                version = "%s.dev%s+%s" % (version[1:], dev, sha)
            else:
                version = version[0][1:]
        except OSError:
            import warnings
            warnings.warn("Could not run ``git describe``")
    elif os.path.exists('pymks.egg-info'):
        from pymks import get_version
        version = get_version()

    return version

setup(name='pymks',
      version=make_version(),
      description='Materials Knowledge Systems in Python (PyMKS)',
      author='David Brough, Daniel Wheeler',
      author_email='david.brough.0416@gmail.com',
      url='http://pymks.org',
      packages=find_packages(),
      package_data={'': ['tests/*.py']},
      )

==> pymks-0.3.4.tar.gz: pymks-0.3.4/setup.py <==
#!/usr/bin/env python

import subprocess
from setuptools import setup, find_packages
import os


def make_version(package_name):
    """Generates a version number using `git describe`.

    Returns:
      version number of the form "3.1.1.dev127+g413ed61".
    """
    def _minimal_ext_cmd(cmd):
        """Run a command in a subprocess.

        Args:
          cmd: list of the command

        Returns:
          output from the command
        """
        # construct minimal environment
        env = {}
        for k in ['SYSTEMROOT', 'PATH']:
            value = os.environ.get(k)
            if value is not None:
                env[k] = value
        # LANGUAGE is used on win32
        env['LANGUAGE'] = 'C'
        env['LANG'] = 'C'
        env['LC_ALL'] = 'C'
        out = subprocess.Popen(cmd,
                               stdout=subprocess.PIPE,
                               env=env).communicate()[0]
        return out

    version = 'unknown'

    if os.path.exists('.git'):
        try:
            out = _minimal_ext_cmd(['git',
                                    'describe',
                                    '--tags',
                                    '--match',
                                    'v*'])
            # ticket:475 - fix for bytecode received in Py3k
            # http://jeetworks.org/node/67
            outdecode = out.decode("utf-8")
            # convert git long-form version string, e.g.,
            # "version-3_1_1-127-g413ed61", into PEP 440 version,
            # e.g., "3.1.1.dev127+g413ed61"
            version = outdecode.strip().split("-")
            if len(version) > 1:
                version, dev, sha = version
                version = "%s.dev%s+%s" % (version[1:], dev, sha)
            else:
                version = version[0][1:]
        except OSError:
            import warnings
            warnings.warn("Could not run ``git describe``")
    elif os.path.exists('pymks.egg-info'):
        from pkg_resources import get_distribution, DistributionNotFound
        try:
            version = get_distribution(package_name).version # pylint: disable=no-member
        except DistributionNotFound: # pragma: no cover
            version = "unknown, try running `python setup.py egg_info`"

    return version


PACKAGE_NAME = "pymks"


setup(name=PACKAGE_NAME,
      version=make_version(PACKAGE_NAME),
      description='Materials Knowledge Systems in Python (PyMKS)',
      author='David Brough, Daniel Wheeler',
      author_email='david.brough.0416@gmail.com',
      url='http://pymks.org',
      packages=find_packages(),
      package_data={'': ['tests/*.py']},
      install_requires=[],
      data_files=['setup.cfg'])
